package com.sun.java.swing;

import java.awt.EventQueue;
import java.util.concurrent.Callable;
import java.awt.AWTEvent;
import java.util.Collections;
import java.util.WeakHashMap;
import sun.awt.EventQueueDelegate;
import sun.awt.SunToolkit;
import java.awt.Component;
import java.awt.Window;
import java.applet.Applet;
import sun.awt.AppContext;
import javax.swing.RepaintManager;
import javax.swing.JComponent;
import java.awt.Container;
import java.util.Map;

public class SwingUtilities3
{
    private static final Object DELEGATE_REPAINT_MANAGER_KEY;
    private static final Map<Container, Boolean> vsyncedMap;
    
    public SwingUtilities3() {
    }
    
    public static void setDelegateRepaintManager(JComponent component, RepaintManager value) {
        AppContext.getAppContext().put(SwingUtilities3.DELEGATE_REPAINT_MANAGER_KEY, Boolean.TRUE);
        component.putClientProperty(SwingUtilities3.DELEGATE_REPAINT_MANAGER_KEY, value);
    }
    
    public static void setVsyncRequested(Container container, boolean b) {
        assert !(!(container instanceof Window));
        if (b) {
            SwingUtilities3.vsyncedMap.put(container, Boolean.TRUE);
        }
        else {
            SwingUtilities3.vsyncedMap.remove(container);
        }
        return;
    }
    
    public static boolean isVsyncRequested(Container container) {
        assert !(!(container instanceof Window));
        return Boolean.TRUE == SwingUtilities3.vsyncedMap.get(container);
    }
    
    public static RepaintManager getDelegateRepaintManager(Component target) {
        RepaintManager repaintManager = null;
        if (Boolean.TRUE == SunToolkit.targetToAppContext(target).get(SwingUtilities3.DELEGATE_REPAINT_MANAGER_KEY)) {
            while (repaintManager == null && target != null) {
                while (target != null && !(target instanceof JComponent)) {
                    target = target.getParent();
                }
                if (target == null) {
                    continue;
                }
                repaintManager = (RepaintManager)((JComponent)target).getClientProperty(SwingUtilities3.DELEGATE_REPAINT_MANAGER_KEY);
                target = target.getParent();
            }
            return repaintManager;
        }
        return repaintManager;
    }
    
    public static void setEventQueueDelegate(Map<String, Map<String, Object>> map) {
        EventQueueDelegate.setDelegate(new EventQueueDelegateFromMap(map));
    }
    
    static {
        DELEGATE_REPAINT_MANAGER_KEY = new StringBuilder("DelegateRepaintManagerKey");
        vsyncedMap = Collections.synchronizedMap(new WeakHashMap());
    }
    
    private static class EventQueueDelegateFromMap implements EventQueueDelegate.Delegate
    {
        private final AWTEvent[] afterDispatchEventArgument;
        private final Object[] afterDispatchHandleArgument;
        private final Callable<Void> afterDispatchCallable;
        private final AWTEvent[] beforeDispatchEventArgument;
        private final Callable<Object> beforeDispatchCallable;
        private final EventQueue[] getNextEventEventQueueArgument;
        private final Callable<AWTEvent> getNextEventCallable;
        
        public EventQueueDelegateFromMap(Map<String, Map<String, Object>> map) {
            Map<Object, Object> map2 = (Map)map.get("afterDispatch");
            this.afterDispatchEventArgument = (AWTEvent[])(AWTEvent[])map2.get("event");
            this.afterDispatchHandleArgument = (Object[])(Object[])map2.get("handle");
            this.afterDispatchCallable = (Callable)map2.get("method");
            Map<Object, Object> map3 = (Map)map.get("beforeDispatch");
            this.beforeDispatchEventArgument = (AWTEvent[])(AWTEvent[])map3.get("event");
            this.beforeDispatchCallable = (Callable)map3.get("method");
            Map<Object, Object> map4 = (Map)map.get("getNextEvent");
            this.getNextEventEventQueueArgument = (EventQueue[])(EventQueue[])map4.get("eventQueue");
            this.getNextEventCallable = (Callable)map4.get("method");
        }
        
        public void afterDispatch(AWTEvent awtEvent, Object o) throws InterruptedException {
            this.afterDispatchEventArgument[0] = awtEvent;
            this.afterDispatchHandleArgument[0] = o;
            try {
                this.afterDispatchCallable.call();
            }
            catch (InterruptedException ex) {
                throw ex;
            }
            catch (RuntimeException ex2) {
                throw ex2;
            }
            catch (Exception cause) {
                throw new RuntimeException(cause);
            }
        }
        
        public Object beforeDispatch(AWTEvent awtEvent) throws InterruptedException {
            this.beforeDispatchEventArgument[0] = awtEvent;
            try {
                return this.beforeDispatchCallable.call();
            }
            catch (InterruptedException ex) {
                throw ex;
            }
            catch (RuntimeException ex2) {
                throw ex2;
            }
            catch (Exception cause) {
                throw new RuntimeException(cause);
            }
        }
        
        public AWTEvent getNextEvent(EventQueue eventQueue) throws InterruptedException {
            this.getNextEventEventQueueArgument[0] = eventQueue;
            try {
                return (AWTEvent)this.getNextEventCallable.call();
            }
            catch (InterruptedException ex) {
                throw ex;
            }
            catch (RuntimeException ex2) {
                throw ex2;
            }
            catch (Exception cause) {
                throw new RuntimeException(cause);
            }
        }
    }
}
